@@ -53,7 +53,7 @@ class Integracao(core.models.Log):
     tipo = models.CharField(max_length=200, null=True)
     url = models.CharField(max_length=500, null=True)
     headers = models.TextField(null=True)
-    data = models.TextField(null=True)
+    bodycore = models.TextField(null=True)
     status_code = models.IntegerField(null=True)
     response = models.TextField(null=True)
 
